"use strict";
/*
 * Kuzzle, a backend software, self-hostable and ready to use
 * to power modern apps
 *
 * Copyright 2015-2022 Kuzzle
 * mailto: support AT kuzzle.io
 * website: http://kuzzle.io
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.IndexCache = void 0;
const kerror = __importStar(require("../../kerror"));
const storageError = kerror.wrap("services", "storage");
class IndexCache {
    constructor() {
        /**
         * Index map: each entry holds a set of collection names
         *
         * Map<index, Set<collection>>
         */
        this.indexes = new Map();
        this.indexes = new Map();
    }
    /**
     * Cache a new index
     *
     * @return true if an index was added, false if there is no modification
     */
    addIndex(index) {
        if (this.indexes.has(index)) {
            return false;
        }
        this.indexes.set(index, new Set());
        return true;
    }
    /**
     * Cache a new collection
     */
    addCollection(index, collection) {
        this.addIndex(index);
        const collections = this.indexes.get(index);
        collections.add(collection);
    }
    /**
     * Check an index existence
     */
    hasIndex(index) {
        return this.indexes.has(index);
    }
    /**
     * Check a collection existence
     */
    hasCollection(index, collection) {
        const collections = this.indexes.get(index);
        if (!collections) {
            return false;
        }
        return collections.has(collection);
    }
    /**
     * Return the list of cached indexes
     */
    listIndexes() {
        return Array.from(this.indexes.keys());
    }
    /**
     * Return the list of an index collections
     *
     * @throws If the provided index does not exist
     */
    listCollections(index) {
        this.assertIndexExists(index);
        return Array.from(this.indexes.get(index));
    }
    /**
     * Remove an index from the cache
     */
    removeIndex(index) {
        this.indexes.delete(index);
    }
    /**
     * Remove a collection from the cache
     */
    removeCollection(index, collection) {
        const collections = this.indexes.get(index);
        if (collections) {
            collections.delete(collection);
        }
    }
    /**
     * Assert that the provided index exists
     *
     * @throws If the index does not exist
     */
    assertIndexExists(index) {
        if (!this.indexes.has(index)) {
            throw storageError.get("unknown_index", index);
        }
    }
    /**
     * Assert that the provided index and collection exist
     */
    assertCollectionExists(index, collection) {
        this.assertIndexExists(index);
        if (!this.indexes.get(index).has(collection)) {
            throw storageError.get("unknown_collection", index, collection);
        }
    }
}
exports.IndexCache = IndexCache;
//# sourceMappingURL=indexCache.js.map