/// <reference types="node" />
import KuzzleEventEmitter from "./event/kuzzleEventEmitter";
import { InstallationConfig, ImportConfig, SupportConfig, StartOptions } from "./../types/Kuzzle";
import { KuzzleConfiguration } from "../types/config/KuzzleConfiguration";
export declare const BACKEND_IMPORT_KEY = "backend:init:import";
declare class Kuzzle extends KuzzleEventEmitter {
    private config;
    private _state;
    private log;
    private rootPath;
    /**
     * Internal index bootstrapper and accessor
     */
    private internalIndex;
    private pluginsManager;
    private tokenManager;
    private passport;
    /**
     * The funnel dispatches messages to API controllers
     */
    private funnel;
    /**
     * The router listens to client requests and pass them to the funnel
     */
    private router;
    /**
     * Statistics core component
     */
    private statistics;
    /**
     * Network entry point
     */
    private entryPoint;
    /**
     * Validation core component
     */
    private validation;
    /**
     * Dump generator
     */
    private dumpGenerator;
    /**
     * Vault component (will be initialized after bootstrap)
     */
    private vault;
    /**
     * AsyncLocalStorage wrapper
     */
    private asyncStore;
    /**
     * Kuzzle internal debugger
     */
    private debugger;
    /**
     * Kuzzle version
     */
    private version;
    private openApiManager;
    /**
     * List of differents imports types and their associated method
     */
    private importTypes;
    private koncorde;
    private secret;
    /**
     * Node unique ID amongst other cluster nodes
     */
    id: string;
    constructor(config: KuzzleConfiguration);
    /**
     * Initializes all the needed components of Kuzzle.
     *
     * @param {Application} - Application Plugin instance
     * @param {Object} - Additional options (import, installations, plugins, secretsFile, support, vaultKey)
     *
     * @this {Kuzzle}
     */
    start(application: any, options?: StartOptions): Promise<void>;
    /**
     * Generates the node ID.
     *
     * This will init the cluster if it's enabled.
     */
    private initKuzzleNode;
    /**
     * Gracefully exits after processing remaining requests
     *
     * @returns {Promise}
     */
    shutdown(): Promise<void>;
    /**
     * Execute multiple handlers only once on any given environment
     *
     * @param {Array<{ id: string, handler: () => void, description?: string }>} installations - Array of unique methods to execute
     *
     * @returns {Promise<void>}
     */
    install(installations: InstallationConfig[]): Promise<void>;
    ask(...args: any[]): Promise<any>;
    emit(...args: any[]): Promise<any>;
    pipe(...args: any[]): Promise<any>;
    private importUserMappings;
    private importMappings;
    private importFixtures;
    private importPermissions;
    /**
     * Check if every import has been done, if one of them is not finished yet, wait for it
     */
    private _waitForImportToFinish;
    private isConfigsEmpty;
    private persistHashedImport;
    /**
     * Load into the app several imports
     *
     * @param {Object} toImport - Contains `mappings`, `onExistingUsers`, `profiles`, `roles`, `userMappings`, `users`
     * @param {Object} toSupport - Contains `fixtures`, `mappings`, `securities` (`profiles`, `roles`, `users`)
     *
     * @returns {Promise<void>}
     */
    loadInitialState(toImport?: ImportConfig, toSupport?: SupportConfig): Promise<void>;
    dump(suffix: any): any;
    hash(input: any): string | Buffer;
    get state(): kuzzleStateEnum;
    set state(value: kuzzleStateEnum);
    /**
     * Register handlers and do a kuzzle dump for:
     * - system signals
     * - unhandled-rejection
     * - uncaught-exception
     */
    registerSignalHandlers(): void;
    dumpAndExit(suffix: any): Promise<void>;
}
export { Kuzzle };
